@@ -150,7 +150,11 @@ def cli():
 @cli.command()
 @click.option("--git-repo", required=True, help="Git repository")
 @click.option("--git-ref", required=True, help="Git reference")
-@click.option("--target-arch", required=True, help="Target architecture")
+@click.option(
+    "--target-arch",
+    required=True,
+    help="Target architecture [arm64|arm|x86|i386|mips|arc|riscv]",
+)
 @click.option(
     "--kconfig",
     required=True,
@@ -158,9 +162,7 @@ def cli():
     help="Kernel kconfig arguments (may be specified multiple times)",
 )
 @click.option(
-    "--toolchain",
-    required=True,
-    help="option to choose between gcc-8, gcc-9, clang-8 and clang-9",
+    "--toolchain", required=True, help="Toolchain [gcc-8|gcc-9|clang-8|clang-9]",
 )
 @click.option(
     "--kconfig-allconfig",
@@ -231,7 +233,11 @@ def get_tux_config(url, retries=3, sleep=3):
 @click.option("--set-name", required=True, help="Set name")
 @click.option("--git-repo", required=True, help="Git repository")
 @click.option("--git-ref", required=True, help="Git reference")
-@click.option("--target-arch", required=False, help="Target architecture")
+@click.option(
+    "--target-arch",
+    required=False,
+    help="Target architecture [arm64|arm|x86|i386|mips|arc|riscv]",
+)
 @click.option(
     "--kconfig",
     required=False,
@@ -239,9 +245,7 @@ def get_tux_config(url, retries=3, sleep=3):
     help="Kernel kconfig arguments (may be specified multiple times)",
 )
 @click.option(
-    "--toolchain",
-    required=False,
-    help="option to choose between gcc-8, gcc-9, clang-8 and clang-9",
+    "--toolchain", required=False, help="Toolchain [gcc-8|gcc-9|clang-8|clang-9]",
 )
 @click.option(
     "--kconfig-allconfig",
@@ -322,9 +326,12 @@ def build_set(
                     )
                 )
 
-        b["kconfig_allconfig"] = params.get(
-            "kconfig_allconfig", b.get("kconfig_allconfig", None)
-        )
+        # kconfig_allconfig is optional api parameter hence it may not be defined
+        # in cli or the set. We need to explicitly set it to None
+        if params.get("kconfig_allconfig") is not None:
+            b["kconfig_allconfig"] = params.get("kconfig_allconfig")
+        elif "kconfig_allconfig" not in b:
+            b["kconfig_allconfig"] = None
 
         build_objects.append(
             tuxbuild.build.Build(
